![alt text](x_start.png)

#*Welcome to Loge python notebook*

*Easy and fast generation of interactive reports with Python*

---

If you are a new Loge user go to Info to get information and try to use it with prepared tutorial.


Please note that this is beta version - for testing.


